@@ -451,7 +451,7 @@ static void gv_wizard_button_clicked(GtkButton * button,
                                  GST_TAG_TITLE, gtk_entry_get_text(GTK_ENTRY(title_entry)),
                                  GST_TAG_ARTIST, g_get_real_name(),
                                  GST_TAG_ALBUM, "Voicegrams",
-                                 GST_TAG_COMMENT, "GNOME 43",
+                                 GST_TAG_COMMENT, "GNOME 44",
                                  GST_TAG_DATE, g_date_time_format_iso8601 (datestamp),
                                  NULL);
 	g_date_time_unref (datestamp);
@@ -479,26 +479,29 @@ static void gv_wizard_close(GtkAssistant * assistant, gpointer data)
 	FILE *voice_pointer = NULL;
 	VoiceInfo *voiceinfo = (VoiceInfo *) data;
 	GDateTime *datestamp = g_date_time_new_now_utc ();
-	gchar *filename_voice =
-	    g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
-			"GNOME.voice", NULL);
+	gchar *filename_voice = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", "GNOME.voice", NULL);
+	gchar *string;
+	char buf[256];
+	GDate d;
+	const char *charset;
+
+	/* Version and current date. */
+	g_date_clear (&d, 1);
+	g_date_set_time_t (&d, time (NULL));
+	g_date_strftime (buf, sizeof (buf), "%s", &d);
+	
 	voice_pointer = fopen(filename_voice, "w");
 	fprintf(voice_pointer, "<voice version='%s'>\n", VERSION);
 	fprintf(voice_pointer, "  <station name='%s' uri='http://%s/GNOME.ogg'>\n",
 		g_get_real_name(),
 		g_get_host_name());
-#if 0
-	fprintf(voice_pointer, "    <location lat='%s' lon='%s'>%s</location>\n",
-		voiceinfo->location->lat,
-		voiceinfo->location->lon,
-		voiceinfo->location->city);
-#endif
-	fprintf(voice_pointer, "    <stream>http://%s%s</stream>\n", g_get_host_name(), "/GNOME.ogg");
+	fprintf(voice_pointer, "    <location>%s</location>\n", g_get_host_name());
+	fprintf(voice_pointer, "    <stream>https://www.gnomevoice.org/stream/data/%s%s</stream>\n", buf, ".voice");
 	fprintf(voice_pointer, "  </station>\n");
 	fprintf(voice_pointer, "</voice>\n");
 	fclose(voice_pointer);
 	g_date_time_unref (datestamp);
-	gst_element_send_event(data, gst_event_new_eos());
+	// gst_element_send_event(data, gst_event_new_eos());
 }
 
 static void gv_wizard_apply(GtkAssistant * assistant, gpointer data)
@@ -551,22 +554,28 @@ main (gint argc, gchar **argv)
 	GtkWidget *introduction;
 	int i = 0;
 	PageInfo page[5] = {
-		{NULL, -1, "Voice 0.4.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
+		{NULL, -1, "Voice 0.6.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
 		{NULL, -1, "Title", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Filename", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Summary", GTK_ASSISTANT_PAGE_SUMMARY, TRUE},		
 		{NULL, -1, "Complete", GTK_ASSISTANT_PAGE_CONFIRM, TRUE},		
 	};
+	VoiceInfo *voinfo;
+	gchar *voice_filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
+					    "GNOME.voice", NULL);
+	voinfo = gnome_voice_file_loader (voinfo,
+					  voice_filename);
+	g_free (voinfo);
 	// gtk_init(&argc, &argv);
 	gtk_clutter_init(&argc, &argv);
 	window = gtk_clutter_window_new ();
 	introduction = gtk_assistant_new();
 	gtk_container_add (GTK_WINDOW (window), introduction);
 	gtk_widget_set_size_request(GTK_WIDGET(introduction), 640, 480);
-	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 0.4.0");
+	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 0.6.0");
 	g_signal_connect(G_OBJECT(introduction), "destroy",
 			 G_CALLBACK(gtk_main_quit), NULL);
-	page[0].widget = gtk_label_new(_("Welcome to Voice 0.4.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
+	page[0].widget = gtk_label_new(_("Welcome to Voice 0.6.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
 	page[1].widget = gtk_box_new(FALSE, 5);
 	title_label = gtk_label_new(_("Title:"));
 	title_entry = gtk_entry_new();
@@ -612,9 +621,7 @@ main (gint argc, gchar **argv)
 	}
 	voice_xml = g_strconcat (GNOME_VOICE_DATADIR, "/gnome-voice.xml", NULL);
 	voiceinfo = (VoiceInfo *)g_new0 (VoiceInfo, 1);
-#if 0	
-	gnome_voice_file_loader (voiceinfo, voice_xml);
-#endif
+	voiceinfo = gnome_voice_file_loader (voiceinfo, voice_xml);
 	g_signal_connect(G_OBJECT(filename_entry), "changed",
 			 G_CALLBACK(gv_wizard_entry_changed), pipeline);
 	g_signal_connect(G_OBJECT(introduction), "cancel",
@@ -646,7 +653,7 @@ main (gint argc, gchar **argv)
 				 GST_TAG_TITLE, g_get_real_name(),
 				 GST_TAG_ARTIST, g_get_real_name(),
 				 GST_TAG_ALBUM, gtk_entry_get_text(filename_entry),
-				 GST_TAG_COMMENT, "Voice 0.4.0",
+				 GST_TAG_COMMENT, "Voice 0.6.0",
 				 GST_TAG_DATE, g_date_time_format_iso8601 (datestamp),
 				 NULL);
 	g_date_time_unref (datestamp);
@@ -719,10 +726,10 @@ main (gint argc, gchar **argv)
         /* oscilloscope_data.oscilloscope_visual = GNOME_VOICE_MARKER (oscilloscope_visual); */
 	/* Create the voice player */
 	player = gst_player_new (NULL, gst_player_g_main_context_signal_dispatcher_new(NULL));
+	gst_player_set_uri (GST_PLAYER (player), voiceinfo->stream->uri);
 #if 0
-	gst_player_set_uri (GST_PLAYER (player), (gchar*)voiceinfo->stream->uri);
-#endif
 	gst_player_set_uri (GST_PLAYER (player), "http://api.perceptron.stream:8000/56.ogg");	
+#endif
 	gst_player_stop (GST_PLAYER (player));
 	gst_player_play(GST_PLAYER (player));
 #if 0
@@ -733,8 +740,6 @@ main (gint argc, gchar **argv)
 	clutter_actor_show (stage);	
 	clutter_actor_show (voicegram);
 	clutter_main ();
-
 	g_main_loop_run(main_loops);
-
 	return (0);
 }
